pub fn list_channels() -> Result<ListChannelsResponse>Expand description
List channels from the gateway, including the daemon PID + socket name.
pub fn list_channels() -> Result<ListChannelsResponse>List channels from the gateway, including the daemon PID + socket name.