stop_gateway

Function stop_gateway 

pub fn stop_gateway(force: bool) -> Result<()>
Stop the gateway daemon.

The daemon refuses to shut down while any live session is running unless force is true (see RPC_ERROR_LIVE_SESSIONS).